import environ

"""The default environment to use."""
DEFAULT_ENVIRONMENT = 'production'

"""The environment variables of the app instance."""
env = environ.Env()

"""Path to the package root - e.g. Django project."""
root_dir = environ.Path(__file__) - 2

"""Path to the base directory of the app instance."""
base_dir = env.path('BASE_DIR', default=str(root_dir - 1))

conf_overwrite = env.bool('CONFIG_PRIORITY_TO_FILE', default=True)

# Load config.env, OS environment variables will take precedence
# if environment variable CONFIG_PRIORITY_TO_FILE is set to False.
#
# This way, if the project is ruled by config file, the config
# is easily update by re-read the file
# and if it is ruled by environment variable, it is simple to
# set environment variable CONFIG_PRIORITY_TO_FILE to False
env.read_env(str(base_dir.path('config.env')), overwrite=conf_overwrite)

"""The Django settings module's name to use."""
DJANGO_SETTINGS_MODULE = env(
    'DJANGO_SETTINGS_MODULE',
    default='{{ cookiecutter.project_slug }}.settings.{}'.format(
        env('ENV', default=DEFAULT_ENVIRONMENT)
    ),
)
